<?php // Exit if accessed directly.
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

    function jws_register_services() {
		$labels = array(
			'name'                => _x( 'services', 'Post Type General Name', 'netfx' ),
			'singular_name'       => _x( 'services', 'Post Type Singular Name', 'netfx' ),
			'menu_name'           => esc_html__( 'Services', 'netfx' ),
			'parent_item_colon'   => esc_html__( 'Parent Item:', 'netfx' ),
			'all_items'           => esc_html__( 'All Items', 'netfx' ),
			'view_item'           => esc_html__( 'View Item', 'netfx' ),
			'add_new_item'        => esc_html__( 'Add New Item', 'netfx' ),
			'add_new'             => esc_html__( 'Add New', 'netfx' ),
			'edit_item'           => esc_html__( 'Edit Item', 'netfx' ),
			'update_item'         => esc_html__( 'Update Item', 'netfx' ),
			'search_items'        => esc_html__( 'Search Item', 'netfx' ),
			'not_found'           => esc_html__( 'Not found', 'netfx' ),
			'not_found_in_trash'  => esc_html__( 'Not found in Trash', 'netfx' ),
		);

		$args = array(
			'label'               => esc_html__( 'services', 'netfx' ),
		    'labels'              => $labels,
            'supports'            => array( 'title', 'editor', 'excerpt', 'thumbnail','page-attributes', 'post-formats', ),
            'taxonomies'          => array( 'services_cat' ),
            'hierarchical'        => true,
            'public'              => true,
            'netfx_ui'             => true,
            'netfx_in_menu'        => true,
            'netfx_in_nav_menus'   => true,
            'netfx_in_admin_bar'   => true,
            'menu_position'       => 5,
            'menu_icon'           => 'dashicons-money',
            'can_export'          => true,
            'has_archive'         => true,
            'exclude_from_search' => false,
            'publicly_queryable'  => true,
            'capability_type'     => 'page',
		);


        if(function_exists('custom_reg_post_type')){
        	custom_reg_post_type( 'services', $args );
        }

		/**
		 * Create a taxonomy category for services
		 *
		 * @uses  Inserts new taxonomy object into the list
		 * @uses  Adds query vars
		 *
		 * @param string  Name of taxonomy object
		 * @param array|string  Name of the object type for the taxonomy object.
		 * @param array|string  Taxonomy arguments
		 * @return null|WP_Error WP_Error if errors, otherwise null.
		 */
		
		$labels = array(
			'name'					=> _x( 'services Categories', 'Taxonomy plural name', 'netfx' ),
			'singular_name'			=> _x( 'services Category', 'Taxonomy singular name', 'netfx' ),
			'search_items'			=> esc_html__( 'Search Categories', 'netfx' ),
			'popular_items'			=> esc_html__( 'Popular services Categories', 'netfx' ),
			'all_items'				=> esc_html__( 'All services Categories', 'netfx' ),
			'parent_item'			=> esc_html__( 'Parent Category', 'netfx' ),
			'parent_item_colon'		=> esc_html__( 'Parent Category', 'netfx' ),
			'edit_item'				=> esc_html__( 'Edit Category', 'netfx' ),
			'update_item'			=> esc_html__( 'Update Category', 'netfx' ),
			'add_new_item'			=> esc_html__( 'Add New Category', 'netfx' ),
			'new_item_name'			=> esc_html__( 'New Category', 'netfx' ),
			'add_or_remove_items'	=> esc_html__( 'Add or remove Categories', 'netfx' ),
			'choose_from_most_used'	=> esc_html__( 'Choose from most used text-domain', 'netfx' ),
			'menu_name'				=> esc_html__( 'Category', 'netfx' ),
		);
	
		$args = array(
			'hierarchical'      => true,
            'labels'            => $labels,
            'netfx_ui'           => true,
            'netfx_admin_column' => true,
            'query_var'         => true,
            'rewrite'           => array( 'slug' => 'services_cat' ),
		);
        

        if(function_exists('custom_reg_taxonomy')){
            custom_reg_taxonomy( 'services_cat', array( 'services' ), $args  );
        }
        
        $labels = array(
            'name' => esc_html__( 'Tags', 'netfx' ),
            'singular_name' => esc_html__( 'Tag',  'netfx'  ),
            'search_items' =>  esc_html__( 'Search Tags' , 'netfx' ),
            'popular_items' => esc_html__( 'Popular Tags' , 'netfx' ),
            'all_items' => esc_html__( 'All Tags' , 'netfx' ),
            'parent_item' => null,
            'parent_item_colon' => null,
            'edit_item' => esc_html__( 'Edit Tag' , 'netfx' ), 
            'update_item' => esc_html__( 'Update Tag' , 'netfx' ),
            'add_new_item' => esc_html__( 'Add New Tag' , 'netfx' ),
            'new_item_name' => esc_html__( 'New Tag Name' , 'netfx' ),
            'separate_items_with_commas' => esc_html__( 'Separate tags with commas' , 'netfx' ),
            'add_or_remove_items' => esc_html__( 'Add or remove tags' , 'netfx' ),
            'choose_from_most_used' => esc_html__( 'Choose from the most used tags' , 'netfx' ),
            'menu_name' => esc_html__( 'Tags','netfx'),
        ); 
    
        $args = array(
            'hierarchical' => false,
            'labels' => $labels,
            'netfx_ui' => true,
            'update_count_callback' => '_update_post_term_count',
            'query_var' => true,
            'rewrite' => array( 'slug' => 'services_tag' ),
        );
        
        if(function_exists('custom_reg_taxonomy')){
            custom_reg_taxonomy( 'services_tag', array( 'services' ), $args  );
        }

	};
add_action( 'init', 'jws_register_services', 1 );