<?php
/**
 * netfx functions and definitions
 *
 * @link https://developer.wordpress.org/themes/basics/theme-functions/
 *
 * @package WordPress
 * @subpackage netfx
 * @since 1.0.0
 */

/** Define THEME */ 
if (!defined('JWS_ABS_PATH')) define('JWS_ABS_PATH', get_template_directory());
if (!defined('JWS_URI_PATH')) define('JWS_URI_PATH', get_template_directory_uri());
if ( ! function_exists( 'netfx_setup' ) ) :
	/**
	 * Sets up theme defaults and registers support for various WordPress features.
	 *
	 * Note that this function is hooked into the after_setup_theme hook, which
	 * runs before the init hook. The init hook is too late for some features, such
	 * as indicating support for post thumbnails.
	 */
	function netfx_setup() {
		/*
		 * Make theme available for translation.
		 * Translations can be filed in the /languages/ directory.
		 * If you're building a theme based on netfx, use a find and replace
		 * to change 'netfx' to the name of your theme in all the template files.
		 */
		load_theme_textdomain( 'netfx', get_template_directory() . '/languages' );

		// Add default posts and comments RSS feed links to head.
		add_theme_support( 'automatic-feed-links' );
        remove_theme_support( 'widgets-block-editor' );
		/*    
		 * Let WordPress manage the document title.
		 * By adding theme support, we declare that this theme does not use a
		 * hard-coded <title> tag in the document head, and expect WordPress to
		 * provide it for us.
		 */
		add_theme_support( 'title-tag' );

		/*
		 * Enable support for Post Thumbnails on posts and pages.
		 *
		 * @link https://developer.wordpress.org/themes/functionality/featured-images-post-thumbnails/
		 */
		add_theme_support( 'post-thumbnails' );
        add_theme_support( 'post-formats', array( 'video','link','quote','audio','gallery'));
		set_post_thumbnail_size( 1568, 9999 );

		// This theme uses wp_nav_menu() in two locations.
		register_nav_menus(
			array(
				'menu-1' => esc_html__( 'Primary', 'netfx' ),
			)
		);

		/*
		 * Switch default core markup for search form, comment form, and comments
		 * to output valid HTML5.
		 */
		add_theme_support(
			'html5',
			array(
				'search-form',
				'comment-form',
				'comment-list',
				'gallery',
				'caption',
			)
		);

		/**
		 * Add support for core custom logo.
		 *
		 * @link https://codex.wordpress.org/Theme_Logo
		 */
		add_theme_support(
			'custom-logo',
			array(
				'height'      => 190,
				'width'       => 190,
				'flex-width'  => false,
				'flex-height' => false,
			)
		);

		// Add theme support for selective refresh for widgets.
		add_theme_support( 'customize-selective-refresh-widgets' );

		// Add support for Block Styles.
		add_theme_support( 'wp-block-styles' );

		// Add support for full and wide align images.
		add_theme_support( 'align-wide' );

		// Add support for editor styles.
		add_theme_support( 'editor-styles' );

		// Enqueue editor styles.
		add_editor_style( 'style-editor.css' );

		// Add support for responsive embedded content.
		add_theme_support( 'responsive-embeds' );
	}
endif;
add_action( 'after_setup_theme', 'netfx_setup' );

/**
 * Register widget area.
 *
 * @link https://developer.wordpress.org/themes/functionality/sidebars/#registering-a-sidebar
 */
function jws_widgets_init() {

    register_sidebar( 
      array(
			'name'          =>  esc_html__( 'Blog Sidebar', 'netfx' ),
			'id'            => 'blog-sidebar',
			'description'   =>  esc_html__( 'Add widgets here to appear in your blog.', 'netfx' ),
			'before_widget' => '<section id="%1$s" class="widget %2$s">',
			'after_widget'  => '</section>',
			'before_title'  => '<h5 class="widget-title">',
			'after_title'   => '</h5>',
	  )
    );
    register_sidebar( 
      array(
			'name'          =>  esc_html__( 'Shop Sidebar', 'netfx' ),
			'id'            => 'sidebar-shop',
			'description'   =>  esc_html__( 'Add widgets here to appear in your shop.', 'netfx' ),
			'before_widget' => '<section id="%1$s" class="widget %2$s">',
			'after_widget'  => '</section>',
			'before_title'  => '<h5 class="widget-title">',
			'after_title'   => '</h5>',
	  )
    );
}
add_action( 'widgets_init', 'jws_widgets_init' );


/**
 * Set the content width in pixels, based on the theme's design and stylesheet.
 *
 * Priority 0 to make it available to lower priority callbacks.
 *
 * @global int $content_width Content width.
 */
function netfx_content_width() {
	// This variable is intended to be overruled from themes.
	// Open WPCS issue: {@link https://github.com/WordPress-Coding-Standards/WordPress-Coding-Standards/issues/1043}.
	// phpcs:ignore WordPress.NamingConventions.PrefixAllGlobals.NonPrefixedVariableFound
	$GLOBALS['content_width'] = apply_filters( 'netfx_content_width', 640 );
}
add_action( 'after_setup_theme', 'netfx_content_width', 0 );

/**
 * Enqueue scripts and styles.
 */
function netfx_scripts() { 
   
        
    global $jws_option;
	$font_main = (!empty($jws_option['font_body']['font-family'])) ? $jws_option['font_body']['font-family'] : 'DM Sans';
    $font1 = (!empty($jws_option['font_h5']['font-family'])) ? $jws_option['font_h5']['font-family'] : 'DM Sans' ;
    $font_button = (!empty($jws_option['font-button']['font-family'])) ? $jws_option['font-button']['font-family'] : 'DM Sans';
    $font_paragraph = (!empty($jws_option['font_paragraph']['font-family'])) ? $jws_option['font_paragraph']['font-family'] : 'DM Sans';
    $font1_check = '';
    $font2_check = '';
     $font3_check = '';
    if(!empty($font1)&&($font1 != $font_main)) {
    		$font1_check='|'.$font1.':300,400,500,600,700'; 	
    }
    if(!empty($font_button)&&($font_button != $font_main)) {
    		$font2_check='|'.$font_button.':300,400,500,600,700'; 	
    }
    if(!empty($font_paragraph)&&($font_paragraph != $font_main)) {
    		$font3_check='|'.$font_paragraph.':300,400,500,600,700'; 	
    }
	if(!empty($font_main)) {
    	wp_enqueue_style( 'jws-frontend-google-fonts-font-main', '//fonts.googleapis.com/css?family='.$font_main.':300,400,500,600,700'.$font1_check.$font2_check.$font3_check, false ); 	
    }
    wp_enqueue_style('font-awesome');
    wp_enqueue_style( 'awesome', JWS_URI_PATH . '/assets/font/awesome/style.css', array(), wp_get_theme()->get( 'Version' ), 'all' );
    wp_enqueue_style( 'jws-default-style', JWS_URI_PATH . '/assets/css/default.css', array(), wp_get_theme()->get( 'Version' ), 'all' );
    wp_enqueue_style( 'evaicon', JWS_URI_PATH . '/assets/font/evaicon/evaicon.css', array(), wp_get_theme()->get( 'Version' ), 'all' );
    wp_enqueue_style( 'jws-icon', JWS_URI_PATH . '/assets/font/jws_icon/jws_icon.css', array(), wp_get_theme()->get( 'Version' ), 'all' );
    wp_enqueue_style( 'owl-carousel', JWS_URI_PATH.'/assets/css/owl.carousel.css', array(), wp_get_theme()->get( 'Version' ), 'all' );
    wp_enqueue_style( 'mediaelementplayer', JWS_URI_PATH.'/assets/css/mediaelementplayer.css', array(), wp_get_theme()->get( 'Version' ), 'all' );
    wp_enqueue_style( 'magnificPopupcss', JWS_URI_PATH.'/assets/css/magnificPopup.css', array(), wp_get_theme()->get( 'Version' ), 'all' );
    wp_enqueue_script( 'jws-slick', JWS_URI_PATH. '/assets/js/slick.min.js', array('js-cookie'), '', true );   
    wp_register_script( 'easypiechart', JWS_URI_PATH. '/assets/js/easypiechart.min.js', array('js-cookie'), '', true );
    wp_enqueue_script( 'appear', JWS_URI_PATH. '/assets/js/appear.min.js', array('js-cookie'), '', true );
    wp_enqueue_script( 'isotope', JWS_URI_PATH. '/assets/js/isotope.js', array('js-cookie'), '', true );
    wp_enqueue_script('masonry');
    wp_enqueue_script( 'SmoothScroll', JWS_URI_PATH. '/assets/js/SmoothScroll.js', array('js-cookie'), '', true ); 
    wp_enqueue_script( 'magnificPopup', JWS_URI_PATH. '/assets/js/magnificPopup.js', array('js-cookie'), '', true );
    wp_enqueue_script( 'js-cookie', JWS_URI_PATH .'/assets/js/jquery-cookie.js', array(), false, true );
    wp_enqueue_script( 'vivus', JWS_URI_PATH. '/assets/js/vivus.min.js', array('js-cookie'), '', true );
    wp_enqueue_script( 'jws-off-canvas', JWS_URI_PATH. '/assets/js/jws-off-canvas.js', array('js-cookie'), '', true );
    wp_register_script( 'addthis-widget', JWS_URI_PATH. '/assets/js/addthis_widget.js', array('js-cookie'), '', true );
    wp_enqueue_script( 'carousel', JWS_URI_PATH. '/assets/js/owl.carousel.js', array('js-cookie'), '', true );
    
    wp_enqueue_script( 'packery-mode', JWS_URI_PATH. '/assets/js/packery-mode.pkgd.min.js', array('js-cookie'), '', true );
    wp_enqueue_script( 'sticky-kit', JWS_URI_PATH. '/assets/js/sticky-kit.js', array('js-cookie'), '', true );
    wp_enqueue_script( 'media-element', JWS_URI_PATH. '/assets/js/mediaelement-and-player.js', array('js-cookie'), '', true );
    wp_enqueue_script( 'jws-mini-cart', JWS_URI_PATH. '/assets/js/mini-cart.js', array('js-cookie'), '', true );
    wp_enqueue_script( 'jws-widget', JWS_URI_PATH. '/assets/js/elementor_widget.js', array('js-cookie'), '', true );
    wp_enqueue_script( 'jws-main', JWS_URI_PATH. '/assets/js/main.js', array('jquery'), '', true );        
    wp_enqueue_script( 'chart', JWS_URI_PATH. '/assets/js/chart.js', array('js-cookie'), '', true ); 
    
     /** Start Woocommerce **/
     
     if (class_exists('Woocommerce')) {
        wp_enqueue_script( 'jws-addtocart', JWS_URI_PATH.'/assets/js/woocommerce/ajax_mn_addtocart.min.js', array('js-cookie'), '', true  );        
          wp_enqueue_script( 'jws-main-woocommerce', JWS_URI_PATH. '/assets/js/woocommerce/main-woocommerce.js', array('js-cookie'), '', true );
       if(is_product() || is_shop() || is_tax() || is_cart() || is_checkout()) {
            
            wp_enqueue_script( 'wc-shop', JWS_URI_PATH. '/assets/js/woocommerce/wc-shop.js', array('js-cookie'), '', true );
            wp_enqueue_script( 'jws-photoswipe', JWS_URI_PATH. '/assets/js/jws-photoswipe-bundle.min.js', array('js-cookie'), '', true );
            wp_enqueue_script( 'pjax', JWS_URI_PATH. '/assets/js/pjax.js', array('js-cookie'), '', true );
        }
     }
     
    /**
     *  Add google Api
     */
     
	 $api_url     = 'https://maps.googleapis.com';

	 if ( isset( $jws_option['google_api'] ) && '' !== $jws_option['google_api'] ) {
	   
		$url = $api_url . '/maps/api/js?key=' . $jws_option['google_api'].'&libraries=places&language=en';
            
	 } else {

		$url = $api_url . '/maps/api/js';
	 }

     wp_register_script( 'jws-google-maps-api', $url, [ 'jquery' ],'', true );
     
     
     $script_name = 'wc-add-to-cart-variation';
    	if ( wp_script_is( $script_name, 'registered' ) && ! wp_script_is( $script_name, 'enqueued' ) ) {
    		wp_enqueue_script( $script_name );
    	}
     if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
    	wp_enqueue_script( 'comment-reply' );
    }
    wp_localize_script('jws-main','MS_Ajax', array(
    	'ajaxurl' => admin_url('admin-ajax.php'),
        'shopurl' => function_exists('wc_get_page_permalink') ? wc_get_page_permalink( 'shop' ) : '',
    	'nextNonce' => wp_create_nonce('myajax-next-nonce'),
        'has_elemetor' => ( did_action( 'elementor/loaded' ) ) ? 'yes' : 'no',
        'metera'  =>  esc_html__('Very weak','netfx'),
        'meterb'  =>  esc_html__('Weak','netfx'),
        'meterc'  =>  esc_html__('Medium','netfx'),
        'meterd'  =>  esc_html__('Strong','netfx'),
        )
    );
     $upload_dir = wp_upload_dir();
    $style_dir = $upload_dir['baseurl'];
    if (file_exists($upload_dir['basedir'] . '/jws-style.css')) {
        wp_enqueue_style(
            'jws-style',
            $style_dir . '/jws-style.css',
			['elementor-frontend','e-animations'],
            filemtime($upload_dir['basedir'] . '/jws-style.css')
        );
    } else {
        wp_enqueue_style( 'jws-style', JWS_URI_PATH.'/assets/css/style.css', array(), '1.0' , false );
        wp_enqueue_style( 'jws-style2', JWS_URI_PATH.'/assets/css/style2.css', array(), '1.0' , false );
    }
    if(!empty($jws_option)) {
       wp_enqueue_style( 'jws-il-style', get_stylesheet_uri() );
	   wp_add_inline_style( 'jws-il-style', jws_custom_css() ); 
    }
            
}
add_action( 'wp_enqueue_scripts', 'netfx_scripts' );




// Update CSS within in Admin
function jws_admin_style() {
  wp_enqueue_style('jws-admin-styles', JWS_URI_PATH.'/assets/css/admin.css');	
}
add_action('admin_enqueue_scripts', 'jws_admin_style');



/**
 * equeue scripts and styles.
 */
 add_filter( 'elementor/frontend/print_google_fonts', '__return_false' );
 add_action( 'elementor/frontend/after_register_styles',function() {
	foreach( [ 'solid', 'regular', 'brands' ] as $style ) {
		wp_deregister_style( 'elementor-icons-fa-' . $style );
	}
}, 20 );
add_action( 'wp_print_styles', 'jws_dequeue_style'  , 100 );	
add_action( 'wp_print_styles', 'jws_dequeue_style' );
function jws_dequeue_style() {
      wp_dequeue_style( 'elementor-icons' );
      wp_dequeue_style( 'rs-icon-set-fa-icon' );
      wp_dequeue_style( 'dashicons' );
      wp_dequeue_style( 'elementor-icons-icomoon' );      
      wp_dequeue_style( 'woocommerce_prettyPhoto' ); 
      wp_dequeue_style( 'jquery-selectBox' );
      wp_dequeue_style( 'redux-google-fonts-jws_option' );      
      wp_dequeue_style( 'elementor-animations' );      
      wp_dequeue_script( 'jquery-slick');
       wp_dequeue_style( 'ywpc-google-fonts' );
       if (class_exists('Woocommerce')) {
         
       if(!is_product() || !is_shop() || !is_tax() || !is_cart() || !is_checkout()) {
            
           wp_dequeue_style( 'ywpc-frontend' );
        }
     }
          
}

add_action( 'after_setup_theme', function() { 
	add_action( 'register_sidebar', function( $sidebar )
	{
    	global $wp_registered_sidebars;
	
	    $id = $sidebar[ 'id' ];
	    $sidebar[ 'before_title' ] = '<h5 class="widget-title subheading heading-size-3">';
	    $sidebar[ 'after_title' ] = '</h5>';

	    $wp_registered_sidebars[ $id ] = $sidebar;
	});
});

/**
 * Enhance the theme by hooking into WordPress.
*/
require JWS_ABS_PATH . '/inc/inc.php';
/* Woo commerce function */
if (class_exists('Woocommerce')) {
	require_once JWS_ABS_PATH . '/woocommerce/wc-template-function.php';
}
// Remove <p> and <br/> from Contact Form 7
add_filter('wpcf7_autop_or_not', '__return_false');

add_action('wp_loaded', 'jws_prefix_output_buffer_start');

function jws_prefix_output_buffer_start() { 
    ob_start("jws_prefix_output_callback"); 
}

function jws_prefix_output_callback($buffer) {
    return preg_replace( "%[ ]type=[\'\"]text\/(javascript|css)[\'\"]%", '', $buffer );
};


function jws_filter_backups_demos($demos)
	{
		$demos_array = array(
			'netfx' => array(
				'title' => esc_html__('Netfx', 'netfx'),
				'screenshot' => 'https://jwsuperthemes.com/import_demo/netfx/screenshot.jpg',
				'preview_link' => 'http://netfx.jwsuperthemes.com/',
			),
		);
        $download_url = 'https://jwsuperthemes.com/import_demo/netfx/dowload-script/';
		foreach ($demos_array as $id => $data) {
			$demo = new FW_Ext_Backups_Demo($id, 'piecemeal', array(
				'url' => $download_url,
				'file_id' => $id,
			));
			$demo->set_title($data['title']);
			$demo->set_screenshot($data['screenshot']);
			$demo->set_preview_link($data['preview_link']);
			$demos[$demo->get_id()] = $demo;
			unset($demo);
		}
		return $demos;
}
add_filter('fw:ext:backups-demo:demos', 'jws_filter_backups_demos');