<?php
/**
 * Class Plugin
 *
 * Main Plugin class
 * @since 1.0
 */
class Plugin {
    /**
     * Instance
     *
     * @since 1.2.0
     * @access private
     * @static
     *
     * @var Plugin The single instance of the class.
     */
    private static $_instance = null;
    /**
     * Instance
     *
     * Ensures only one instance of the class is loaded or can be loaded.
     *
     * @since 1.2.0
     * @access public
     *
     * @return Plugin An instance of the class.
     */
    public static function instance() {
        if (is_null(self::$_instance)) {
            self::$_instance = new self();
        }
        return self::$_instance;
    }
    public function enqueue_editor_scripts() {
        wp_register_script('jws-query-control', JWS_URI_PATH . '/inc/elementor_widget/control/js/query.js', array(), '', true);
    }
    public function get_scripts($name_js_ccs) {
        wp_enqueue_script($name_js_ccs);
    }
    /**
     * Include Control files
     *
     * Load controls files
     *
     * @since 1.2.0
     * @access private
     */
    private function include_control_files() {
        require_once (JWS_ABS_PATH . '/inc/elementor_widget/control/query.php');
    }
    public function register_controls() {
        // Its is now safe to include Control files
        $this->include_control_files();
        $controls_manager = \Elementor\Plugin::$instance->controls_manager;
        $controls_manager->register_control('jws-query-posts', new JwsElementor\Control\Query());
    }
    /**
     * Register Widgets
     *
     * Register new Elementor widgets.
     *
     * @since 1.2.0
     * @access public
     */
    public function register_widgets($widgets_manager) {
        
        // Its is now safe to include Widgets files

        require_once (JWS_ABS_PATH . '/inc/elementor_widget/widgets/account/account.php');
        require_once (JWS_ABS_PATH . '/inc/elementor_widget/widgets/menu_nav/menu_nav.php');
        require_once (JWS_ABS_PATH . '/inc/elementor_widget/widgets/video_popup/video_popup.php');
        require_once (JWS_ABS_PATH . '/inc/elementor_widget/widgets/info_box/info_box.php');
        require_once (JWS_ABS_PATH . '/inc/elementor_widget/widgets/testimonial_slider/testimonial_slider.php');
        require_once (JWS_ABS_PATH . '/inc/elementor_widget/widgets/blog/blog.php');
        require_once (JWS_ABS_PATH . '/inc/elementor_widget/widgets/blog_tabs/blog_tabs.php');
        require_once (JWS_ABS_PATH . '/inc/elementor_widget/widgets/team/team.php');
        require_once (JWS_ABS_PATH . '/inc/elementor_widget/widgets/breadcrumbs/breadcrumbs.php');
        require_once (JWS_ABS_PATH . '/inc/elementor_widget/widgets/tab/tab.php');
        require_once (JWS_ABS_PATH . '/inc/elementor_widget/widgets/services/services.php');
        require_once (JWS_ABS_PATH . '/inc/elementor_widget/widgets/icon_box/icon_box.php');
        require_once (JWS_ABS_PATH . '/inc/elementor_widget/widgets/button/button.php');
        require_once (JWS_ABS_PATH . '/inc/elementor_widget/widgets/pricing_table/pricing_table.php');
        require_once (JWS_ABS_PATH . '/inc/elementor_widget/widgets/logo.php');
        require_once (JWS_ABS_PATH . '/inc/elementor_widget/widgets/search.php');
        require_once (JWS_ABS_PATH . '/inc/elementor_widget/widgets/mini_cart/mini_cart.php');
        require_once (JWS_ABS_PATH . '/inc/elementor_widget/widgets/canvas.php');
        require_once (JWS_ABS_PATH . '/inc/elementor_widget/widgets/dropdown_text.php');
        require_once (JWS_ABS_PATH . '/inc/elementor_widget/widgets/banner/banner.php');
        require_once (JWS_ABS_PATH . '/inc/elementor_widget/widgets/heading_and_content/heading_and_content.php');
        require_once (JWS_ABS_PATH . '/inc/elementor_widget/widgets/product_listing/product_listing.php');
        require_once (JWS_ABS_PATH . '/inc/elementor_widget/widgets/contact_form7/contact_form7.php');
        require_once (JWS_ABS_PATH . '/inc/elementor_widget/widgets/menu_listing.php');
        require_once (JWS_ABS_PATH . '/inc/elementor_widget/widgets/shows/shows.php');
        require_once (JWS_ABS_PATH . '/inc/elementor_widget/widgets/jws_gallery.php');
        require_once (JWS_ABS_PATH . '/inc/elementor_widget/widgets/tongle_switch.php');
        require_once (JWS_ABS_PATH . '/inc/elementor_widget/widgets/map/map.php');
        require_once (JWS_ABS_PATH . '/inc/elementor_widget/widgets/login-form/login-form.php');
        require_once (JWS_ABS_PATH . '/inc/elementor_widget/widgets/chart/chart.php');
        require_once (JWS_ABS_PATH . '/inc/elementor_widget/widgets/progress.php');
        require_once (JWS_ABS_PATH . '/inc/elementor_widget/widgets/agencys_form/agencys_form.php');
         require_once (JWS_ABS_PATH . '/inc/elementor_widget/widgets/aven_chart/aven_chart.php');
         require_once (JWS_ABS_PATH . '/inc/elementor_widget/widgets/table/table.php');
        // Register Widgets
        \Elementor\Plugin::instance()->widgets_manager->register_widget_type(new Elementor\Account());
        \Elementor\Plugin::instance()->widgets_manager->register_widget_type(new Elementor\Nav_Menu());
        \Elementor\Plugin::instance()->widgets_manager->register_widget_type(new Elementor\Video_popup());
        \Elementor\Plugin::instance()->widgets_manager->register_widget_type(new Elementor\Info_Box());
        \Elementor\Plugin::instance()->widgets_manager->register_widget_type(new Elementor\Testimonial_Slider());
        \Elementor\Plugin::instance()->widgets_manager->register_widget_type(new Elementor\Jws_Blog());
        \Elementor\Plugin::instance()->widgets_manager->register_widget_type(new Elementor\Blog_Tab());
        \Elementor\Plugin::instance()->widgets_manager->register_widget_type(new Elementor\Jws_Team());
        \Elementor\Plugin::instance()->widgets_manager->register_widget_type(new Elementor\JWS_Button());
        \Elementor\Plugin::instance()->widgets_manager->register_widget_type(new Elementor\JWS_Services());
        \Elementor\Plugin::instance()->widgets_manager->register_widget_type(new Elementor\Jws_Breadcrumbs());
        \Elementor\Plugin::instance()->widgets_manager->register_widget_type(new Elementor\Jws_tab());
        \Elementor\Plugin::instance()->widgets_manager->register_widget_type(new Elementor\Jws_Price_Table());
        \Elementor\Plugin::instance()->widgets_manager->register_widget_type(new Elementor\Logo());
        \Elementor\Plugin::instance()->widgets_manager->register_widget_type(new Elementor\Search());
        \Elementor\Plugin::instance()->widgets_manager->register_widget_type(new Elementor\Menu_Cart());
        \Elementor\Plugin::instance()->widgets_manager->register_widget_type(new Elementor\Offcanvas());
        \Elementor\Plugin::instance()->widgets_manager->register_widget_type(new Elementor\Dropdown_Text());
        \Elementor\Plugin::instance()->widgets_manager->register_widget_type(new Elementor\Banner());
        \Elementor\Plugin::instance()->widgets_manager->register_widget_type(new Elementor\Heading_Content());
        \Elementor\Plugin::instance()->widgets_manager->register_widget_type(new Elementor\Product_Listing());
        \Elementor\Plugin::instance()->widgets_manager->register_widget_type(new Elementor\Jws_cf7());
        \Elementor\Plugin::instance()->widgets_manager->register_widget_type(new Elementor\JWS_Menu_Liting());
        \Elementor\Plugin::instance()->widgets_manager->register_widget_type(new Elementor\shows());
        \Elementor\Plugin::instance()->widgets_manager->register_widget_type(new Elementor\Jws_Gallery());
        \Elementor\Plugin::instance()->widgets_manager->register_widget_type(new Elementor\GoogleMap());
        \Elementor\Plugin::instance()->widgets_manager->register_widget_type(new Elementor\Login_form());
        \Elementor\Plugin::instance()->widgets_manager->register_widget_type(new Elementor\JWS_Icon_Box());
        \Elementor\Plugin::instance()->widgets_manager->register_widget_type(new Elementor\Jws_Tongle_Switch());
        \Elementor\Plugin::instance()->widgets_manager->register_widget_type(new Elementor\PieCharts());
        \Elementor\Plugin::instance()->widgets_manager->register_widget_type(new Elementor\JWS_Progress());
        \Elementor\Plugin::instance()->widgets_manager->register_widget_type(new Elementor\Agencys_form());
        \Elementor\Plugin::instance()->widgets_manager->register_widget_type(new Elementor\jws_Aven_Charts());
         \Elementor\Plugin::instance()->widgets_manager->register_widget_type(new Elementor\Jws_Table());
    }
    public function register_categoris() {
        \Elementor\Plugin::$instance->elements_manager->add_category('jws-elements', ['title' => esc_html__('JWS Themes Widget', 'netfx'), 'icon' => 'fa fa-plug', ], 1);
    }
    /**
     *  Plugin class constructor
     *
     * Register plugin action hooks and filters
     *
     * @since 1.2.0
     * @access public
     */
    public function __construct() {
        include_once ('jws_grid.php');
         include_once ('row-sticky.php');
         include_once ('shade_animation.php');
        add_action('init', array($this, 'register_categoris'));
        // Register widgets
        add_action('elementor/widgets/widgets_registered', [$this, 'register_widgets']);
        // Register controls
        add_action('elementor/controls/controls_registered', [$this, 'register_controls']);
        // Editor Scripts
        add_action('elementor/editor/before_enqueue_scripts', [$this, 'enqueue_editor_scripts']);
    }
}
// Instantiate Plugin Class
Plugin::instance();

/**
* Custom Widget Default
*/

add_action( 'elementor/element/icon-box/section_icon/before_section_end', function( $element, $args ) {

     $element->add_control(
			'hover_select',
			[
				'label' => esc_html__( 'Hover Change All Content', 'netfx' ),
				'type' => \Elementor\Controls_Manager::SELECT,
				'options' => [
					'none' => esc_html__( 'none', 'netfx' ),
                    'all' => esc_html__( 'All Content', 'netfx' ),
				],
				'default' => 'none',
                'prefix_class' => 'elementor_icon_hover_',
			]
	);
    
    $element->add_control(
			'hover_all',
			[
				'label' => esc_html__( 'Color Hover', 'netfx' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}}.elementor_icon_hover_all:hover  .elementor-icon-box-content .elementor-icon-box-description , {{WRAPPER}}.elementor_icon_hover_all:hover  .elementor-icon-box-content .elementor-icon-box-title , {{WRAPPER}}.elementor_icon_hover_all:hover .elementor-icon' => 'color: {{VALUE}}',
				],
                'condition' => [
						  'hover_select' => 'all',
				],
			]
	);
  
	
}, 10, 2 );

add_action( 'elementor/element/icon-box/section_style_icon/before_section_end', function( $element, $args ) {

        $element->add_group_control(
			\Elementor\Group_Control_Box_Shadow::get_type(),
			[
				'name' => 'box_shadow',
				'label' => esc_html__( 'Box Shadow', 'netfx' ),
				'selector' => '{{WRAPPER}} .elementor-icon',
			]
		);

  
	
}, 10, 2 ); 