<?php
namespace Elementor;
use Elementor\Widget_Base;
use Elementor\Controls_Manager;

/**
 * Elementor image widget.
 *
 * Elementor widget that displays an image into the page.
 *
 * @since 1.0.0
 */
class Logo extends Widget_Base
{

    /**
     * Get widget name.
     *
     * Retrieve image widget name.
     *
     * @since 1.0.0
     * @access public
     *
     * @return string Widget name.
     */
    public function get_name()
    {
        return 'jws-logo';
    }

    /**
     * Get widget title.
     *
     * Retrieve image widget title.
     *
     * @since 1.0.0
     * @access public
     *
     * @return string Widget title.
     */
    public function get_title()
    {
        return esc_html__('Jws Logo', 'netfx');
    }

    /**
     * Get widget icon.
     *
     * Retrieve image widget icon.
     *
     * @since 1.0.0
     * @access public
     *
     * @return string Widget icon.
     */
    public function get_icon()
    {
        return 'eicon-image';
    }

    /**
     * Get widget categories.
     *
     * Retrieve the list of categories the image widget belongs to.
     *
     * Used to determine where to display the widget in the editor.
     *
     * @since 2.0.0
     * @access public
     *
     * @return array Widget categories.
     */
    public function get_categories()
    {
        return [ 'basic' ];
    }

    /**
     * Get widget keywords.
     *
     * Retrieve the list of keywords the widget belongs to.
     *
     * @since 2.1.0
     * @access public
     *
     * @return array Widget keywords.
     */


    /**
     * Register image widget controls.
     *
     * Adds different input fields to allow the user to change and customize the widget settings.
     *
     * @since 1.0.0
     * @access protected
     */
    protected function _register_controls()
    {
        $this->start_controls_section(
            'section_image',
            [
                'label' => esc_html__('Image', 'netfx'),
            ]
        );

        $this->add_control(
            'image_logo',
            [
                'label' => esc_html__('Choose Image', 'netfx'),
                'type' => Controls_Manager::MEDIA,
                
            ]
        );
        $this->add_responsive_control(
				'logo_width',
				[
					'label' 		=> esc_html__( 'Logo Width', 'netfx' ),
					'type' 			=> Controls_Manager::SLIDER,
					'range' 		=> [
						'px' 		=> [
							'min' => 1,
							'max' => 300,
							'step' => 1,
						],
                    ],
                    'default' => [
                        'unit' => 'px',
                        'size' => 147,
                    ],
					'selectors' 	=> [
						'{{WRAPPER}} img' => 'width: {{SIZE}}px;height:auto;display:block;margin:auto;',
                        '{{WRAPPER}} svg' => 'width: {{SIZE}}px;display:block;margin:auto;',
                        '{{WRAPPER}} .logo-vertical img' => 'min-width: {{SIZE}}px',
					],
				]
		);
        $this->add_control(
    			'logo_vertical',
    			[
    				'label' => esc_html__( 'Logo Vertical', 'netfx' ),
    				'type' => \Elementor\Controls_Manager::SWITCHER,
    				'label_on' => esc_html__( 'Yes', 'netfx' ),
    				'label_off' => esc_html__( 'N0', 'netfx' ),
    				'return_value' => 'true',
    				'default' => 'false',
    			]
    		);
        $this->add_responsive_control(
            'align',
            [
                'label' => esc_html__('Alignment', 'netfx'),
                'type' => Controls_Manager::CHOOSE,
                'options' => [
                    'left' => [
                        'title' => esc_html__('Left', 'netfx'),
                        'icon' => 'eicon-text-align-left',
                    ],
                    'center' => [
                        'title' => esc_html__('Center', 'netfx'),
                        'icon' => 'eicon-text-align-center',
                    ],
                    'right' => [
                        'title' => esc_html__('Right', 'netfx'),
                        'icon' => 'eicon-text-align-right',
                    ],
                ],
                'selectors' => [
                    '{{WRAPPER}} .elementor-widget-container' => 'text-align: {{VALUE}};',
                ],
            ]
        );
        $this->add_control(
			'link',
			[
				'label' => esc_html__( 'Link', 'netfx' ),
				'type' => Controls_Manager::URL,
				'placeholder' => esc_html__( 'https://your-link.com', 'netfx' ),
			]
		);
    }

    /**
     * Render image widget output on the frontend.
     *
     * Written in PHP and used to generate the final HTML.
     *
     * @since 1.0.0
     * @access protected
     */
    protected function render()
    {
        $settings = $this->get_settings_for_display();
        $logo_verical = $settings['logo_vertical'] ? 'logo-vertical': '';
        global $jws_option;
        if (isset($settings['image_logo']['url']) && $settings['image_logo']['url'] != "") {
            echo  '<a href="'. $settings['link']['url'] .'"><img src="'. $settings['image_logo']['url'] .'" class="'.esc_attr($logo_verical).'" alt="#"></a>';
        }else if (isset($jws_option['logo']['url']) && !empty($jws_option['logo']['url'])) { 
            $src = $jws_option['logo']['url'];
                    
           echo  '<a href="'.get_home_url().'" class="'.esc_attr($logo_verical).'">';
    			 echo '<img src="'. $src .'" alt="#">';
    	
               
            echo '</a>';
          ?>  
        <?php }else{
            echo  '<a href="'.get_home_url().'" class="logo-text">'. $jws_option['logo_text'] .'</a>';
        }
        ?>
        <?php
    }

    /**
     * Render image widget output in the editor.
     *
     * Written as a Backbone JavaScript template and used to generate the live preview.
     *
     * @since 1.0.0
     * @access protected
     */
    protected function _content_template()
    {
    }
}
