<?php

/**
 * WooCommerce mylist functions
 *
 * @package jws
 */


if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly



function woocommerce_maybe_add_multiple_shows_to_cart( $url = false ) {
    // Make sure WC is installed, and add-to-cart qauery arg exists, and contains at least one comma.
    if ( ! class_exists( 'WC_Form_Handler' ) || empty( $_REQUEST['add-to-cart'] ) || false === strpos( $_REQUEST['add-to-cart'], ',' ) ) {
        return;
    }
 
    // Remove WooCommerce's hook, as it's useless (doesn't handle multiple shows).
    remove_action( 'wp_loaded', array( 'WC_Form_Handler', 'add_to_cart_action' ), 20 );
 
    $show_ids = explode( ',', $_REQUEST['add-to-cart'] );
    $count       = count( $show_ids );
    $number      = 0;
 
    foreach ( $show_ids as $id_and_quantity ) {
        // Check for quantities defined in curie notation (<show_id>:<show_quantity>)
        // https://dsgnwrks.pro/snippets/woocommerce-allow-adding-multiple-shows-to-the-cart-via-the-add-to-cart-query-string/#comment-12236
        $id_and_quantity = explode( ':', $id_and_quantity );
        $show_id = $id_and_quantity[0];
 
        $_REQUEST['quantity'] = ! empty( $id_and_quantity[1] ) ? absint( $id_and_quantity[1] ) : 1;
 
        if ( ++$number === $count ) {
            // Ok, final item, let's send it back to woocommerce's add_to_cart_action method for handling.
            $_REQUEST['add-to-cart'] = $show_id;
 
            return WC_Form_Handler::add_to_cart_action( $url );
        }
 
        $show_id        = apply_filters( 'woocommerce_add_to_cart_show_id', absint( $show_id ) );
        $was_added_to_cart = false;
        $adding_to_cart    = wc_get_show( $show_id );
 
        if ( ! $adding_to_cart ) {
            continue;
        }
 
        $add_to_cart_handler = apply_filters( 'woocommerce_add_to_cart_handler', $adding_to_cart->get_type(), $adding_to_cart );
 
        // Variable show handling
        if ( 'variable' === $add_to_cart_handler ) {
            woo_hack_invoke_private_method( 'WC_Form_Handler', 'add_to_cart_handler_variable', $show_id );
 
        // Grouped shows
        } elseif ( 'grouped' === $add_to_cart_handler ) {
            woo_hack_invoke_private_method( 'WC_Form_Handler', 'add_to_cart_handler_grouped', $show_id );
 
        // Custom Handler
        } elseif ( has_action( 'woocommerce_add_to_cart_handler_' . $add_to_cart_handler ) ){
            do_action( 'woocommerce_add_to_cart_handler_' . $add_to_cart_handler, $url );
 
        // Simple shows
        } else {
            woo_hack_invoke_private_method( 'WC_Form_Handler', 'add_to_cart_handler_simple', $show_id );
        }
    }
}
 
add_action( 'wp_loaded', 'woocommerce_maybe_add_multiple_shows_to_cart', 15 ); 
 
 
/**
 * Invoke class private method
 *
 * @since   0.1.0
 *
 * @param   string $class_name
 * @param   string $methodName
 *
 * @return  mixed
 */
function woo_hack_invoke_private_method( $class_name, $methodName ) {
    if ( version_compare( phpversion(), '5.3', '<' ) ) {
        throw new Exception( 'PHP version does not support ReflectionClass::setAccessible()', __LINE__ );
    }
 
    $args = func_get_args();
    unset( $args[0], $args[1] );
    $reflection = new ReflectionClass( $class_name );
    $method = $reflection->getMethod( $methodName );
    $method->setAccessible( true );
 
    $args = array_merge( array( $class_name ), $args );
    return call_user_func_array( array( $method, 'invoke' ), $args );
}



if ( ! function_exists( 'jws_mylist_shortcode' ) ) {
	/**
	 * WooCommerce mylist page shortcode.
	 *
	 * @since 4.5
	 */
	function jws_mylist_shortcode() {
		if ( !class_exists('Woocommerce') ) return;
		ob_start();
             jws_get_mylistd_shows_table(); 
             
		return ob_get_clean();
	}
   
   if(function_exists('insert_shortcode')) {
	   insert_shortcode( 'jws_mylist', 'jws_mylist_shortcode' ); 
   }
}



if ( ! function_exists( 'jws_add_to_mylist' ) ) {
    
	/**
	 * Add show to comapre
	 *
	 * @since 4.5
	 */
	function jws_add_to_mylist() {

		$id = sanitize_text_field( $_GET['id'] );

		$cookie_name = jws_mylist_cookie_name();

		if ( jws_is_show_in_mylist( $id ) ) {
			jws_mylist_json_response();
		}

		$shows = jws_get_mylistd_shows();

		$shows[] = $id;

		setcookie( $cookie_name, json_encode( $shows ), 0, COOKIEPATH, COOKIE_DOMAIN, false, false );

		$_COOKIE[$cookie_name] = json_encode( $shows );

		jws_mylist_json_response();
	}

	add_action( 'wp_ajax_jws_add_to_mylist', 'jws_add_to_mylist' );
	add_action( 'wp_ajax_nopriv_jws_add_to_mylist', 'jws_add_to_mylist' );
}


if ( ! function_exists( 'jws_add_to_mylist_btn' ) ) {
	/**
	 * Add show to comapre button
	 *
	 * @since 4.5
	 */
	function jws_add_to_mylist_btn() {
		global $show;

        $class_added = '';
        $ids = jws_get_mylistd_shows();

        if(in_array(get_the_ID(), $ids)) {
            $class_added = ' added'; 
        }
        $url = jws_get_mylist_page_url();
        if($url) { 
    		echo '<a href="' . esc_url( jws_get_mylist_page_url() ) . '" class="button jws-mylist-btn'.esc_attr($class_added).'" data-id="' . esc_attr( $show->get_id() ) . '">
                <i class="jws-icon-icon_heart_alt"></i>
                <span class="notadd">'.esc_html__('Add to mylist','netfx').'</span>
                <span class="added">'.esc_html__('Browse mylist','netfx').'</span>
            </a>';
        }
	}
}

if ( ! function_exists( 'jws_add_to_mylist_single_btn' ) ) {
	/**
	 * Add show to comapre button on single show
	 *
	 * @since 4.4
	 */
	function jws_add_to_mylist_single_btn() {
		global $show;
		echo '<a class="jws-mylistsg-btn" data-added-text="' . esc_html__('mylist shows', 'netfx') . '" data-id="' . esc_attr( $show->get_id() ) . '"><span class="jws-icon-icon_heart_alt"></span></a>';
	}
}


if ( ! function_exists( 'jws_mylist_json_response' ) ) {
	/**
	 * Compare JSON reponse.
	 *
	 * @since 4.5
	 */
	function jws_mylist_json_response() {
		$count = 0;
		$shows = jws_get_mylistd_shows();

		ob_start();

		jws_get_mylistd_shows_table();

		$table_html = ob_get_clean();

		if ( is_array( $shows ) ) {
			$count = count( $shows );
		}

		wp_send_json( array(
			'count' => $count,
			'table' => $table_html,
		) );
	}
}

if ( ! function_exists( 'jws_get_mylist_page_url' ) ) {
    
	/**
	 * Get mylist page ID.
	 *
	 * @since 4.5
	 */
	function jws_get_mylist_page_url() {
	    global $jws_option;
		$page_id = (isset($jws_option['mylist_page'])) ? $jws_option['mylist_page'] : '';
        if(empty($page_id)) {return false;}
		return get_permalink( $page_id );
	}
}


if ( ! function_exists( 'jws_remove_from_mylist' ) ) {
	/**
	 * Add show to comapre
	 *
	 * @since 4.5
	 */
	function jws_remove_from_mylist() {

		$id = sanitize_text_field( $_GET['id'] );

		$cookie_name = jws_mylist_cookie_name();

		if ( ! jws_is_show_in_mylist( $id ) ) {
			jws_mylist_json_response();
		}

		$shows = jws_get_mylistd_shows();

		foreach ( $shows as $k => $show_id ) {
			if ( intval( $id ) == $show_id ) {
				unset( $shows[ $k ] );
			}
		}

		if ( empty( $shows ) ) {
			setcookie( $cookie_name, false, 0, COOKIEPATH, COOKIE_DOMAIN, false, false );
			$_COOKIE[$cookie_name] = false;
		} else {
			setcookie( $cookie_name, json_encode( $shows ), 0, COOKIEPATH, COOKIE_DOMAIN, false, false );
			$_COOKIE[$cookie_name] = json_encode( $shows );
		}

		jws_mylist_json_response();
	}

	add_action( 'wp_ajax_jws_remove_from_mylist', 'jws_remove_from_mylist' );
	add_action( 'wp_ajax_nopriv_jws_remove_from_mylist', 'jws_remove_from_mylist' );
}


if ( ! function_exists( 'jws_is_show_in_mylist' ) ) {
	/**
	 * Is show in mylist
	 *
	 * @since 4.5
	 */
	function jws_is_show_in_mylist( $id ) {
		$list = jws_get_mylistd_shows();

		return in_array( $id, $list, true );
	}
}


if ( ! function_exists( 'jws_get_mylist_count' ) ) {
	/**
	 * Get mylist number.
	 *
	 * @since 4.5
	 */
	function jws_get_mylist_count() {
		$count = 0;
		$shows = jws_get_mylistd_shows();

		if ( is_array( $shows ) ) {
			$count = count( $shows );
		}

		return $count;
	}
}


if ( ! function_exists( 'jws_mylist_cookie_name' ) ) {
	/**
	 * Get mylist cookie namel.
	 *
	 * @since 4.5
	 */
	function jws_mylist_cookie_name() {
		$name = 'jws_mylist_list';

        if ( is_multisite() ) $name .= '_' . get_current_blog_id();

        return $name;

	}
}


if ( ! function_exists( 'jws_get_mylistd_shows' ) ) {
	/**
	 * Get mylistd shows IDs array
	 *
	 * @since 4.5
	 */
	function jws_get_mylistd_shows() {
		$cookie_name = jws_mylist_cookie_name();
        return isset( $_COOKIE[ $cookie_name ] ) ? json_decode( wp_unslash( $_COOKIE[ $cookie_name ] ), true ) : array();
	}
}

if ( ! function_exists( 'jws_is_shows_have_field' ) ) {
	/**
	 * Checks if the shows have such a field.
	 *
	 * @since 3.4
	 */
	function jws_is_shows_have_field( $field_id, $shows ) {
		foreach ( $shows as $show_id => $show ) {
			if ( isset( $show[ $field_id ] ) && ( ! empty( $show[ $field_id ] ) && '-' !== $show[ $field_id ] && 'N/A' !== $show[ $field_id ] ) ) {
				return true;
			}
		}

		return false;
	}
}


if ( ! function_exists( 'jws_get_mylistd_shows_table' ) ) {
	/**
	 * Get mylistd shows data table HTML
	 *
	 * @since 4.5
	 */
	function jws_get_mylistd_shows_table() {
		$shows = jws_get_mylistd_shows_data();
		$fields = jws_get_mylist_fields();
        global $jws_option;
		$empty_mylist_text = $jws_option['empty_mylist_text'];

		?>
		<div class="jws-mylist-table">
			<?php
			if ( ! empty( $shows ) ) {
				array_unshift( $shows, array() );
				foreach ( $fields as $field_id => $field ) {
					if ( ! jws_is_shows_have_field( $field_id, $shows ) ) {
						continue;
					}
					?>

						<table class="jws-mylist-row">
                            <thead>
                    			<tr>
                    				<th class="title_mylist"><?php echo esc_html('show Detail','netfx'); ?></th>
                                    <th class="title_mylist"><?php echo esc_html('Price','netfx'); ?></th>
                    				<th class="title_mylist"><?php echo esc_html('Stock Status','netfx'); ?></th>
                                    <th class="title_mylist"></th>
                    			</tr>
                			</thead>
                            <tbody>
    							<?php $all_id = array(); foreach ( $shows as $show_id => $show) :   ?>
    								<?php if ( ! empty( $show ) ) : $all_id[] = $show['id']; ?>
    									<tr class="jws-mylist-col">
    										<?php jws_mylist_display_field( $field_id, $show ); ?>
    									</tr>
    								<?php endif; ?>
    
    							<?php endforeach ?>
                            </tbody>
						</table>
                        <div class="add_all_show">
                            <?php 
                                $show_ids = implode(',', $all_id) ;
                                $add_to_cart_url = add_query_arg( 'add-to-cart', $show_ids );
                                if(isset($jws_option['shop_layout']) && $jws_option['shop_layout'] != 'rent') { ?>
                                    <a href="<?php echo esc_url_raw( $add_to_cart_url); ?>" data-show_id="<?php echo esc_attr($show_ids); ?>"><?php esc_html_e('Add all to cart', 'netfx'); ?></a>
                                <?php } ?>
                        </div>
					<?php
				}	
			} else {
				?>
					<p class="jws-empty-mylist">
						<?php esc_html_e('mylist is empty.', 'netfx'); ?>
					</p>
					<?php if ( $empty_mylist_text ) : ?>
						<div class="jws-empty-page-text"><?php echo wp_kses( $empty_mylist_text, array('p' => array(), 'h1' => array(), 'h2' => array(), 'h3' => array(), 'strong' => array(), 'em' => array(), 'span' => array(), 'div' => array() , 'br' => array()) ); ?></div>
					<?php endif; ?>
					<p class="return-to-shop">
						<a class="button" href="<?php echo esc_url( wc_get_page_permalink( 'shop' ) ); ?>">
							<?php esc_html_e( 'Return to shop', 'netfx' ); ?>
						</a>
					</p>
				<?php
			}

			?>
			<div class="mylist-loader"></div>
		</div>
		<?php
	}
}


if ( ! function_exists( 'jws_get_mylist_fields' ) ) {
	/**
	 * Get mylist fields data.
	 *
	 * @since 4.5
	 */
	function jws_get_mylist_fields() {
		$fields = array(
			'basic' => ''
		);

		return $fields;
	}
}


if ( ! function_exists( 'jws_mylist_display_field' ) ) {
	/**
	 * Get mylist fields data.
	 *
	 * @since 4.5
	 */
	function jws_mylist_display_field( $field_id, $show ) {
        global $jws_option;
		$type = $field_id;

		if ( 'pa_' === substr( $field_id, 0, 3 ) ) {
			$type = 'attribute';
		}
		
		switch ( $type ) {
			case 'basic':
					echo '<td class="jws_mylist_detail">
                           <a class="show-image" href="' . get_permalink( $show['id'] ) . '">' . $show['basic']['image']. '</a>
					      <h5 class="show-title"><a href="' . get_permalink( $show['id'] ) . '">' . $show['basic']['title']. '</a></h5>
                    </td>';
					echo '<td class="price">
    						'.wp_kses( $show['basic']['price'],'' ).'
                            '.$show['basic']['rating'].'
					</td>';
                    echo '<td class="stock">
						'.wp_kses( $show['basic']['stock'],'' ).'
					</td>';
                    echo '<td class="mylist_action">
                        '.apply_filters( 'jws_mylist_add_to_cart_btn', $show['basic']['add_to_cart'] ).'
                        <a href="#" class="jws-mylist-remove" data-id="' . esc_attr( $show['id'] ) . '"><span class="remove-loader"></span><span class="jws-icon-icon_close-1"></span></a>
                    </td>';				
			break;

			case 'attribute':

					echo wp_kses( $show[ $field_id ],'' );
			
				break;

			case 'weight':
				if ( $show[ $field_id ] ) {
					$unit = $show[ $field_id ] !== '-' ? $jws_option['woocommerce_weight_unit'] : '';
					echo wc_format_localized_decimal( $show[ $field_id ] ) . ' ' . esc_attr( $unit );
				} 
				break;

			default:
				echo wp_kses( $show[ $field_id ],'' );
				break;
		}
	}
}


if ( ! function_exists( 'jws_get_mylistd_shows_data' ) ) {
	/**
	 * Get mylistd shows data
	 *
	 * @since 4.5
	 */
	function jws_get_mylistd_shows_data() {
		$ids = jws_get_mylistd_shows();

		if ( empty( $ids ) ) {
			return array();
		}

		$args = array(
			'include' => $ids,
		);

		$shows = wc_get_shows( $args );

		$shows_data = array();

		$fields = jws_get_mylist_fields();

		$fields = array_filter( $fields, function(  $field ) {
			return 'pa_' === substr( $field, 0, 3 );
		}, ARRAY_FILTER_USE_KEY );

		$divider = '-';

		foreach ( $shows as $show ) {
			$rating_count = $show->get_rating_count();
			$average = $show->get_average_rating();

			$shows_data[ $show->get_id() ] = array(
				'basic' => array(
					'title' => $show->get_title() ? $show->get_title() : $divider,
					'image' => $show->get_image() ? $show->get_image() : $divider,
					'rating' => wc_get_rating_html_compare( $average, $rating_count ),
					'price' => $show->get_price_html() ? $show->get_price_html() : $divider,
                    'stock' => jws_mylist_avnetfxility_html( $show ),
					'add_to_cart' => jws_mylist_add_to_cart_html( $show ) ? jws_mylist_add_to_cart_html( $show ) :$divider,
				),
				'id' => $show->get_id(),

			);

			foreach ( $fields as $field_id => $field_name ) {
				if ( taxonomy_exists( $field_id ) ) {
					$shows_data[ $show->get_id() ][ $field_id ] = array();
					$terms = get_the_terms( $show->get_id(), $field_id );
					if ( ! empty( $terms ) ) {
						foreach ( $terms as $term ) {
							$term = sanitize_term( $term, $field_id );
							$shows_data[ $show->get_id() ][ $field_id ][] = $term->name;
						}
					} else {
						$shows_data[ $show->get_id() ][ $field_id ][] = '-';
					}
					$shows_data[ $show->get_id() ][ $field_id ] = implode( ', ', $shows_data[ $show->get_id() ][ $field_id ] );
				}
			}
		}

		return $shows_data;
	}
}


